Registrazione | OiRA

Temi

# Registrazione

## Perché devo registrarmi?

La prima cosa che ti sarà chiesto di fare quando inizierai la tua prima valutazione dei rischi è creare un account OiRA - si tratta di un procedimento semplice e rapido.

La registrazione ti permette di accedere in qualsiasi momento per visualizzare i tuoi dati, proseguire valutazioni precedenti o avviarne di nuove.

Grazie alla registrazione il sistema OiRA può salvare tutte le tue sessioni, e i tuoi dati saranno sempre disponibili.

Leggi la nostra politica in materia di privacy per sapere come trattiamo i tuoi dati personali.

## Che differenza c’è tra registrarsi come utente e fare una sessione di prova?

La sessione di prova consente alle parti interessate di farsi un’idea dello strumento prima di decidere se registrarsi. Tuttavia, poiché durante una sessione di prova i tuoi dati non vengono salvati, non potrai recuperare in un momento successivo le informazioni che hai inserito. Nella sessione di prova non puoi stampare nessuna relazione, mentre la registrazione del tuo account ti permette di documentare integralmente la tua valutazione dei rischi.

## Registrare un nuovo account

Questa è la tua prima visita? Per iniziare esegui queste semplici azioni:

1.) Fai clic su «Registrazione» per visualizzare il modulo di registrazione.

Modulo di registrazione.

2.) Inserisci il tuo indirizzo e-mail e scegli una password (ripeti password).

3.) Fai clic su «Avanti» per registrare il tuo nuovo account.

4.) Per continuare, leggi e accetta la politica in materia di privacy.

Ora sarai collegato con il sistema OiRA.

## Accedere a un account esistente

Se sei già registrato, puoi accedere al tuo account in questo modo:

1.) Apri il modulo di accesso. Ogni volta che cercherai di accedere a OiRA, apparirà un collegamento al modulo di accesso, finché non avrai effettuato l’accesso.

Modulo di accesso.

2.) Inserisci il tuo indirizzo e-mail e la password.

3.) Accedi facendo clic sul pulsante «Accedi».

Dopo aver effettuato l’accesso, vedrai la schermata seguente. Qui puoi iniziare una nuova valutazione dei rischi o tornare alle valutazioni dei rischi avviate in precedenza.

Il pannello di controllo.

Inizia una nuova valutazione dei rischi assegnandole un titolo (ad esempio «La-mia-impresa 2018-07-03») o accedi a una delle tue valutazioni precedenti. Tutte le tue valutazioni dei rischi sono salvate per essere consultate in futuro, a meno che tu non decida di cancellarle.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More